(function () {

if (!app.selection || !app.selection.length)
	return;

var divisions = [ ];

/* doing a query is faster than creating a new KSView and
 * enumerating every division object, since that will fetch
 * each full division record from the server anyway.
 */
var ksql = new KSQuery();
ksql.command("select maid 96 nameidnt");
ksql.execute(function (row) {
	if (row[0] && typeof row[0] === "string")
		divisions.push({ label: row[0], value: row[1] });
});

divisions.sort(function (a, b) {
	return(a.label.localeCompare(b.label));
});
divisions.unshift({ label: "No Change", value: 1000000 }, "-", { label: "Uncategorized", value: 0 }, "-");

return({
	version: 1,
	setup: {
		title: "Move Computers",
		id: "com.sassafras.bulkmove",
		fields: [
			{
				id: "login",
				label: "Set Login To:",
				type: "menu",
				default: localStorage.getItem("login"),
				options: [
					{ label: "No Change", value: 1000000 },
					"-",
					{ label: "Dedicated", value: 0 },
					{ label: "Leased", value: 1 },
					{ label: "Dormant", value: 2 },
					{ label: "Excluded", value: 3 }
				]
			},
			{
				id: "division",
				label: "Set Division To:",
				type: "menu",
				default: localStorage.getItem("division"),
				options: divisions
			},
			{
				id: "lifestage",
				label: "Set Lifecycle Stage To:",
				type: "menu",
				default: localStorage.getItem("lifestage"),
				options: [
					{ label: "No Change", value: 1000000 },
					"-",
					{ label: "Deployed", value: 0 },
					{ label: "Maintenance", value: 1 },
					{ label: "Retired", value: 2 },
					{ label: "Ordered", value: 3 },
					{ label: "Acquired", value: 4 },
					{ label: "Stocked", value: 5 },
					{ label: "Missing", value: 6 },
					{ label: "Disposed", value: 7 },
					{ label: "Salvaged", value: 8 }
				]
			},
			{
				id: "anchor",
				label: "Set Anchor To:",
				type: "menu",
				default: localStorage.getItem("anchor"),
				options: [
					{ label: "No Change", value: 1000000 },
					"-",
					{ label: "Anchored", value: 1 },
					{ label: "Unanchored", value: 0 }
				]
			},
			{
				id: "autoupdate",
				label: "Set Auto-update To:",
				type: "menu",
				default: localStorage.getItem("autoupdate"),
				options: [
					{ label: "No Change", value: 1000000 },
					"-",
					{ label: "Auto-update", value: 1 },
					{ label: "Do not Auto-update", value: 0 }
				]
			},
			{
				id: "autologout",
				label: "Set Auto-logout To:",
				type: "menu",
				default: localStorage.getItem("autologout"),
				options: [
					{ label: "No Change", value: 1000000 },
					"-",
					{ label: "Auto-logout", value: 1 },
					{ label: "Do not Auto-logout", value: 0 }
				]
			},
			{
				id: "availability",
				label: "Set Map Availability To:",
				type: "menu",
				default: localStorage.getItem("availability"),
				options: [
					{ label: "No Change", value: 1000000 },
					"-",
					{ label: "Physical and Remote Logins", value: 0 },
					{ label: "Physical Logins Only", value: 1 },
					{ label: "Remote Logins Only", value: 2 },
					{ label: "Not Displayed", value: 3 }
				]
			},
			{
				id: "dualboot",
				label: "Set Dual Boot To:",
				type: "menu",
				default: localStorage.getItem("dualboot"),
				options: [
					{ label: "No Change", value: 1000000 },
					"-",
					{ label: "Single OS", value: 0 },
					{ label: "Dual OS Boot", value: 1 }
				]
			}
		]
	},
	proceed: function (params) {
		localStorage.setItem("login", params.login);
		localStorage.setItem("division", params.division);
		localStorage.setItem("lifestage", params.lifestage);
		localStorage.setItem("anchor", params.anchor);
		localStorage.setItem("autoupdate", params.autoupdate);
		localStorage.setItem("autologout", params.autologout);
		localStorage.setItem("availability", params.availability);
		localStorage.setItem("dualboot", params.dualboot);
		app.selection.forEach(function (obj) {
			if (params.login < 1000000)
				obj.logon = params.login;
			if (params.division < 1000000)
				obj.divisionid = params.division;
			if (params.lifestage < 1000000)
				obj.lifestage = params.lifestage;
			if (params.anchor < 1000000)
				obj.anchored = params.anchor;
			if (params.autoupdate < 1000000)
				obj.autoupdate = params.autoupdate;
			if (params.autologout < 1000000)
				obj.logoutdisconnected = params.autologout;
			if (params.availability < 1000000)
				obj.availability = params.availability;
			if (params.dualboot < 1000000)
				obj.dualboot = params.dualboot;
			obj.commit();
		});
	}
});

})();
